# pfinance
Python financial mathematics library.

## Installation
### Using pip

- run `pip install pfinance`

### Building from source

- clone the repo
- run `python setup.py bdist_wheel`

## Publishing to PyPI

Package builds are automatically published to PyPI on each version bump. Version changes should follow standard [semantic versioning guidelines](https://semver.org/).

## TODO list (incomprehensive)
- add content
  - decide what content we actually want in this. Just functions? Models?
- add a requirements.txt for packages

## Stuff in the venv
- wheel
- setuptools
- twine
- pytest
- pytest-runner
